==> wifi_list-1.0.4.tar.gz: android/src/main/kotlin/com/example/wifi_list/WifiListPlugin.kt <==
package com.example.wifi_list

import android.content.Context
import android.net.wifi.WifiManager
import android.os.Build
import androidx.annotation.NonNull;
import androidx.core.content.ContextCompat
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** WifiListPlugin */
public class WifiListPlugin: FlutterPlugin, MethodCallHandler {

var context:Context? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
//    println("onAttachedToEngine")
//println(flutterPluginBinding.getApplicationContext())
      onAttachedToEngine(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
  }

    private fun onAttachedToEngine(context: Context,messager:BinaryMessenger){
        val channel = MethodChannel(messager, "wifi_list")
        channel.setMethodCallHandler(this);
        this.context = context
    }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
//      println("registerWith")
      val channel = MethodChannel(registrar.messenger(), "wifi_list")
      channel.setMethodCallHandler(WifiListPlugin())
//      val test = registrar.context().applicationContext.getSystemService(Context.WIFI_SERVICE) as WifiManager
    }
  }


  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    val wifiManager2 = this.context!!.getSystemService(Context.WIFI_SERVICE) as WifiManager
    val retList = ArrayList<Map<String,Any>>()
    val results = wifiManager2.scanResults
    results.forEach { res ->
//      println("call" + res.SSID)
      val ret = HashMap<String,Any>()
      ret.put("ssid",res.SSID)
      ret.put("bssid",res.BSSID)
      ret.put("frequency",res.frequency)
      ret.put("level",res.level)
      ret.put("centerFreq0",res.centerFreq0)
      ret.put("centerFreq1",res.centerFreq1)
        ret.put("channelWidth",res.channelWidth)
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M){
            ret.put("opratorFriendlyName",res.operatorFriendlyName.toString())
            ret.put("venueName",res.venueName.toString())
        }else{
            ret.put("opratorFriendlyName","")
            ret.put("venueName","")
        }

      retList.add(ret)
    }


    if (call.method == "getWifiList") {
      result.success(retList)
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
  }
}

==> wifi_list-1.0.5.tar.gz: android/src/main/kotlin/com/example/wifi_list/WifiListPlugin.kt <==
package com.example.wifi_list

import android.content.Context
import android.net.wifi.WifiManager
import android.os.Build
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** WifiListPlugin */
public class WifiListPlugin: FlutterPlugin, MethodCallHandler {

var context:Context? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
//    println("onAttachedToEngine")
//println(flutterPluginBinding.getApplicationContext())
      onAttachedToEngine(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
  }

    private fun onAttachedToEngine(context: Context,messager:BinaryMessenger){
        val channel = MethodChannel(messager, "wifi_list")
        channel.setMethodCallHandler(this);
        this.context = context
    }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
//      println("registerWith")
//      val channel = MethodChannel(registrar.messenger(), "wifi_list")
//      channel.setMethodCallHandler(WifiListPlugin())
//      val test = registrar.context().applicationContext.getSystemService(Context.WIFI_SERVICE) as WifiManager

        val instance = WifiListPlugin()
        instance.onAttachedToEngine(registrar.context(), registrar.messenger())
    }
  }


  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    val wifiManager2 = this.context!!.getSystemService(Context.WIFI_SERVICE) as WifiManager
    val retList = ArrayList<Map<String,Any>>()
    val results = wifiManager2.scanResults
    results.forEach { res ->
//      println("call" + res.SSID)
      val ret = HashMap<String,Any>()
      ret.put("ssid",res.SSID)
      ret.put("bssid",res.BSSID)
      ret.put("frequency",res.frequency)
      ret.put("level",res.level)
      ret.put("centerFreq0",res.centerFreq0)
      ret.put("centerFreq1",res.centerFreq1)
        ret.put("channelWidth",res.channelWidth)
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M){
            ret.put("opratorFriendlyName",res.operatorFriendlyName.toString())
            ret.put("venueName",res.venueName.toString())
        }else{
            ret.put("opratorFriendlyName","")
            ret.put("venueName","")
        }

      retList.add(ret)
    }


    if (call.method == "getWifiList") {
      result.success(retList)
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
  }
}
